summaryrefslogtreecommitdiffstats
path: root/smtreemodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'smtreemodel.h')
-rw-r--r--smtreemodel.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/smtreemodel.h b/smtreemodel.h
index 46f852f..698a2ce 100644
--- a/smtreemodel.h
+++ b/smtreemodel.h
@@ -23,8 +23,9 @@ class SmTreeModel : public QAbstractItemModel {
int rowCount(const QModelIndex &parent) const;
int columnCount(const QModelIndex &parent) const;
// index and flags
QModelIndex index(int row, int column, const QModelIndex &parent) const;
+ QModelIndex parent(const QModelIndex &child) const;
Qt::ItemFlags flags(const QModelIndex &index) const;
// headers + data
@@ -23,8 +23,9 @@ class SmTreeModel : public QAbstractItemModel {
int rowCount(const QModelIndex &parent) const;
int columnCount(const QModelIndex &parent) const;
- // index and flags
+ // index, parent and flags
QModelIndex index(int row, int column, const QModelIndex &parent) const;